@@ -19,6 +19,7 @@
 
 import base64
 import mutagen.flac
+import mutagen.ogg
 import mutagen.oggflac
 import mutagen.oggspeex
 import mutagen.oggtheora
@@ -42,18 +43,28 @@ class VCommentFile(File):
                 if name == "date":
                     # YYYY-00-00 => YYYY
                     value = sanitize_date(value)
-                elif name == 'performer' and value.endswith(')'):
+                elif name == 'performer':
                     # transform "performer=Joe Barr (Piano)" to "performer:Piano=Joe Barr"
-                    start = value.rfind(' (')
-                    if start > 0:
-                        name += ':' + value[start + 2:-1]
-                        value = value[:start]
+                    name += ':'
+                    if value.endswith(')'):
+                        start = value.rfind(' (')
+                        if start > 0:
+                            name += value[start + 2:-1]
+                            value = value[:start]
                 elif name == "fingerprint" and value.startswith("MusicMagic Fingerprint"):
                     name = "musicip_fingerprint"
                     value = value[22:]
-                elif name == "tracktotal":
+                elif name == "tracktotal" and "totaltracks" not in file.tags:
                     name = "totaltracks"
                 metadata.add(name, value)
+        if self._File == mutagen.flac.FLAC:
+            for image in file.pictures:
+                metadata.add_image(image.mime, image.data)
+        try:
+            for index, data in enumerate(file["COVERART"]):
+                metadata.add_image(file["COVERARTMIME"][index], base64.standard_b64decode(data))
+        except KeyError:
+            pass
         self._info(metadata, file)
         return metadata
 
@@ -152,3 +163,23 @@ class OggVorbisFile(VCommentFile):
     def _info(self, metadata, file):
         super(OggVorbisFile, self)._info(metadata, file)
         metadata['~format'] = self.NAME
+
+def OggAudioFile(filename):
+    """Generic Ogg audio file."""
+    options = [OggFLACFile, OggSpeexFile, OggVorbisFile]
+    fileobj = file(filename, "rb")
+    results = []
+    try:
+        header = fileobj.read(128)
+        results = [
+            (option._File.score(filename, fileobj, header), option.__name__, option)
+            for option in options]
+    finally:
+        fileobj.close()
+    results.sort()
+    if not results or results[-1][0] <= 0:
+        raise mutagen.ogg.error("unknown Ogg audio format")
+    return results[-1][2](filename)
+
+OggAudioFile.EXTENSIONS = [".oga"]
+OggAudioFile.NAME = "Ogg Audio"
