@@ -23,6 +23,7 @@ import re
 import sys
 import unicodedata
 from PyQt4 import QtCore
+from encodings import rot_13;
 
 
 def needs_read_lock(func):
@@ -236,8 +237,15 @@ def translate_artist(name, sortname):
     """'Translate' the artist name by reversing the sortname."""
     for c in name:
         ctg = unicodedata.category(c)
-        if ctg[0] not in ("P", "Z") and ctg != "Nd" and unicodedata.name(c).find("LATIN") == -1:
-            return " & ".join(map(_reverse_sortname, sortname.split("&")))
+        if ctg[0] == "L" and unicodedata.name(c).find("LATIN") == -1:
+            for separator in (" & ", "; "):
+                if separator in sortname:
+                    parts = sortname.split(separator)
+                    break
+            else:
+                parts = [sortname]
+                separator = ""
+            return separator.join(map(_reverse_sortname, parts))
     return name
 
 
@@ -279,3 +287,6 @@ def call_next(func):
             next(result=result)
     func_wrapper.__name__ = func.__name__
     return func_wrapper
+
+def rot13(input):
+    return u''.join(unichr(rot_13.encoding_map.get(ord(c), ord(c))) for c in input)
\ No newline at end of file
